---
title: Getting Started
description: Api usage
published: false
date: 2024-12-28T22:26:17.950Z
tags: developers
editor: markdown
dateCreated: 2024-12-28T20:10:42.650Z
---

# API Usage

This guide explains how to integrate the new and improved VehiclesPlus API (v3) into your project.

## Adding VehiclesPlus to Your Project

To use the VehiclesPlus API in your plugin, follow these steps:

### Step 1: Add VehiclesPlus to Your Dependencies

Ensure VehiclesPlus is added as a dependency in your project. To always use the latest version, update your dependency configuration as shown below:

Maven (`pom.xml`):

```xml
<repository>
    <id>sbdevelopment-repo</id>
    <url>https://repo.sbdevelopment.tech/releases</url>
</repository>

<dependency>
    <groupId>tech.sbdevelopment</groupId>
    <artifactId>vehiclesplus</artifactId>
    <version>latest</version>
</dependency>
```

Gradle (`build.gradle`):

```gradle
repositories {
    maven {
        url 'https://repo.sbdevelopment.tech/releases'
    }
}

dependencies {
    implementation 'tech.sbdevelopment:vehiclesplus:latest'
}
```

> **Note**: Using `latest` ensures that your project always fetches the most recent release, but it might cause issues if breaking changes are introduced. For more stability, consider specifying a specific version (e.g., `3.0.2`).
{.is-info}

## Examples

For usage examples, please visit the [VehiclesPlus Examples Page](https://docs.sbdevelopment.tech/en/vehiclesplus-v3/api/examples).

## API Documentation

For additional details and advanced usage refer to the official [VehiclesPlus Javadoc](https://sbdevelopment.tech/javadoc/vehiclesplus-v3/index.html).